@@ -1,4 +1,4 @@
-# Copyright (C) 2020-2022 Greenbone Networks GmbH
+# Copyright (C) 2020-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -15,7 +15,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# pylint: disable=too-many-lines
+# pylint: disable=too-many-lines, line-too-long
 
 import unittest
 from datetime import datetime
@@ -28,14 +28,9 @@ from pontos.release.main import parse_args
 from pontos.release.release import ReleaseReturnValue, release
 from pontos.terminal.terminal import Terminal
 from pontos.testing import temp_git_repository
-from pontos.version.errors import VersionError
-from pontos.version.go import GoVersionCommand
-from pontos.version.version import (
-    Version,
-    VersionCalculator,
-    VersionCommand,
-    VersionUpdate,
-)
+from pontos.version import VersionError, VersionUpdate
+from pontos.version.commands import GoVersionCommand
+from pontos.version.schemes._pep440 import PEP440Version
 
 
 def mock_terminal() -> MagicMock:
@@ -52,21 +47,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_version(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2")
-        next_version = Version("1.0.0.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2")
+        next_version = PEP440Version("1.0.0.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -107,8 +102,11 @@ class ReleaseTestCase(unittest.TestCase):
             ],
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)]
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ]
         )
 
         self.assertEqual(
@@ -148,21 +146,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_patch(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2")
-        next_version = Version("1.0.0.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2")
+        next_version = PEP440Version("1.0.0.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -174,10 +172,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -206,8 +201,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -247,21 +245,22 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_calendar(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("23.2.0")
-        next_version = Version("23.2.1.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        today = datetime.today()
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version(f"{today.year % 100}.{today.month}.0")
+        next_version = PEP440Version(f"{today.year % 100}.{today.month}.1.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -273,12 +272,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_calculator = MagicMock(spec=VersionCalculator)
-        version_calculator.next_calendar_version.return_value = release_version
-        version_command_mock.get_version_calculator.return_value = (
-            version_calculator
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -289,8 +283,6 @@ class ReleaseTestCase(unittest.TestCase):
                 "123",
                 "--release-type",
                 "calendar",
-                "--next-version",
-                "23.2.1.dev1",
             ]
         )
 
@@ -307,11 +299,12 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_calculator.next_calendar_version.assert_called_once_with(
-            current_version
-        )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)]
+
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ]
         )
 
         self.assertEqual(
@@ -325,20 +318,22 @@ class ReleaseTestCase(unittest.TestCase):
         git_mock.return_value.commit.assert_has_calls(
             [
                 call(
-                    "Automatic release to 23.2.0",
+                    f"Automatic release to {release_version}",
                     verify=False,
                     gpg_signing_key="123",
                 ),
                 call(
                     "Automatic adjustments after release\n\n"
-                    "* Update to version 23.2.1.dev1\n",
+                    f"* Update to version {next_version}\n",
                     verify=False,
                     gpg_signing_key="123",
                 ),
             ]
         )
         git_mock.return_value.tag.assert_called_once_with(
-            "v23.2.0", gpg_key_id="123", message="Automatic release to 23.2.0"
+            f"v{release_version}",
+            gpg_key_id="123",
+            message=f"Automatic release to {release_version}",
         )
 
         self.assertEqual(released, ReleaseReturnValue.SUCCESS)
@@ -351,21 +346,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_minor(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.1.0")
-        next_version = Version("0.1.1.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.1.0")
+        next_version = PEP440Version("0.1.1.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -377,10 +372,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -409,8 +401,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -450,21 +445,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_major(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("1.0.0")
-        next_version = Version("1.0.1.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("1.0.0")
+        next_version = PEP440Version("1.0.1.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -476,10 +471,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -508,8 +500,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -549,21 +544,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_alpha(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2a1")
-        next_version = Version("0.0.2a1+dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2a1")
+        next_version = PEP440Version("0.0.2a1+dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -575,10 +570,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -605,8 +597,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -646,21 +641,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_beta(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2b1")
-        next_version = Version("0.0.2b1+dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2b1")
+        next_version = PEP440Version("0.0.2b1+dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -672,10 +667,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -702,8 +694,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -743,21 +738,21 @@ class ReleaseTestCase(unittest.TestCase):
         "pontos.release.release.ReleaseCommand._create_changelog",
         autospec=True,
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_release_candidate(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2rc1")
-        next_version = Version("0.0.2rc1+dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2rc1")
+        next_version = PEP440Version("0.0.2rc1+dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -769,10 +764,7 @@ class ReleaseTestCase(unittest.TestCase):
                 changed_files=["MyProject.conf"],
             ),
         ]
-        version_command_mock.get_current_version.return_value = current_version
-        version_command_mock.get_version_calculator.return_value = (
-            VersionCalculator()
-        )
+        command_mock.get_current_version.return_value = current_version
 
         _, token, args = parse_args(
             [
@@ -799,8 +791,11 @@ class ReleaseTestCase(unittest.TestCase):
                 call(follow_tags=True, remote=None),
             ],
         )
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         self.assertEqual(
@@ -876,13 +871,11 @@ class ReleaseTestCase(unittest.TestCase):
             released, ReleaseReturnValue.PROJECT_SETTINGS_NOT_FOUND
         )
 
-    @patch("pontos.release.release.gather_project", autospec=True)
-    def test_no_release_error(self, gather_project_mock: MagicMock):
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.get_current_version.side_effect = VersionError(
-            "An error"
-        )
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
+    def test_no_release_error(self, gather_commands_mock: MagicMock):
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.get_current_version.side_effect = VersionError("An error")
 
         _, token, args = parse_args(
             [
@@ -905,16 +898,14 @@ class ReleaseTestCase(unittest.TestCase):
 
         self.assertEqual(released, ReleaseReturnValue.NO_RELEASE_VERSION)
 
-    @patch("pontos.release.release.gather_project", autospec=True)
-    def test_no_release(self, gather_project_mock: MagicMock):
-        version_command_mock = MagicMock(spec=VersionCommand)
-        version_calculator_mock = MagicMock(spec=VersionCalculator)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.get_current_version.return_value = None
-        version_command_mock.get_version_calculator.return_value = (
-            version_calculator_mock
-        )
-        version_calculator_mock.next_patch_version.return_value = None
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
+    def test_no_release(
+        self,
+        gather_commands_mock: MagicMock,
+    ):
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.get_current_version.return_value = None
 
         _, token, args = parse_args(
             [
@@ -938,14 +929,14 @@ class ReleaseTestCase(unittest.TestCase):
         self.assertEqual(released, ReleaseReturnValue.NO_RELEASE_VERSION)
 
     @patch("pontos.release.release.Git", autospec=True)
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_has_tag(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         git_mock: MagicMock,
     ):
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         git_mock.return_value.list_tags.return_value = ["v0.0.1"]
 
         _, token, args = parse_args(
@@ -975,18 +966,16 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_release", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_update_version_error(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = VersionError(
-            "An error"
-        )
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = VersionError("An error")
 
         _, token, args = parse_args(
             [
@@ -1011,8 +1000,8 @@ class ReleaseTestCase(unittest.TestCase):
 
         git_mock.return_value.push.assert_not_called()
 
-        version_command_mock.update_version.assert_called_once_with(
-            Version("0.0.1")
+        command_mock.update_version.assert_called_once_with(
+            PEP440Version("0.0.1"), force=False
         )
 
         create_release_mock.assert_not_awaited()
@@ -1030,20 +1019,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_github_create_release_failure(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1108,21 +1097,21 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_update_version_after_release_error(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
         create_changelog_mock.return_value = "A Changelog"
-        version_command_mock.update_version.side_effect = [
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1156,8 +1145,11 @@ class ReleaseTestCase(unittest.TestCase):
             follow_tags=True, remote=None
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)]
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ]
         )
 
         self.assertEqual(
@@ -1184,20 +1176,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_to_specific_git_remote(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1246,8 +1238,11 @@ class ReleaseTestCase(unittest.TestCase):
             (release_version, "foo", "A Changelog"),
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         git_mock.return_value.add.assert_called_with("MyProject.conf")
@@ -1270,20 +1265,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_without_git_prefix(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1332,8 +1327,11 @@ class ReleaseTestCase(unittest.TestCase):
             (release_version, "foo", "A Changelog"),
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         git_mock.return_value.add.assert_called_with("MyProject.conf")
@@ -1354,20 +1352,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_github_api(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         github_api_mock: AsyncMock,
         git_mock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1423,8 +1421,11 @@ class ReleaseTestCase(unittest.TestCase):
             prerelease=False,
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         git_mock.return_value.add.assert_called_with("MyProject.conf")
@@ -1445,20 +1446,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_github_api_pre_release(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         github_api_mock: AsyncMock,
         git_mock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1a1")
-        next_version = Version("0.0.1a1+dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1a1")
+        next_version = PEP440Version("0.0.1a1+dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1514,8 +1515,11 @@ class ReleaseTestCase(unittest.TestCase):
             prerelease=True,
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)],
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ],
         )
 
         git_mock.return_value.add.assert_called_with("MyProject.conf")
@@ -1547,7 +1551,7 @@ class ReleaseTestCase(unittest.TestCase):
         create_release_mock: AsyncMock,
         git_mock,
     ):
-        release_version = Version("0.0.2")
+        release_version = PEP440Version("0.0.2")
 
         create_changelog_mock.return_value = "A Changelog"
         _, token, args = parse_args(["release", "--release-type", "patch"])
@@ -1599,21 +1603,21 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_release", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_with_changelog(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_release_mock: AsyncMock,
         get_last_release_version_mock: MagicMock,
         cc_git_mock: MagicMock,
         git_mock: MagicMock,
     ):
-        current_version = Version("0.0.1")
-        release_version = Version("0.0.2")
-        next_version = Version("1.0.0.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.1")
+        release_version = PEP440Version("0.0.2")
+        next_version = PEP440Version("1.0.0.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1690,8 +1694,11 @@ class ReleaseTestCase(unittest.TestCase):
             ]
         )
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)]
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ]
         )
 
         self.assertEqual(
@@ -1730,20 +1737,20 @@ class ReleaseTestCase(unittest.TestCase):
     @patch(
         "pontos.release.release.ReleaseCommand._create_changelog", autospec=True
     )
-    @patch("pontos.release.release.gather_project", autospec=True)
+    @patch("pontos.release.release.Project._gather_commands", autospec=True)
     def test_release_local(
         self,
-        gather_project_mock: MagicMock,
+        gather_commands_mock: MagicMock,
         create_changelog_mock: MagicMock,
         create_release_mock: AsyncMock,
         git_mock,
     ):
-        current_version = Version("0.0.0")
-        release_version = Version("0.0.1")
-        next_version = Version("0.0.2.dev1")
-        version_command_mock = MagicMock(spec=VersionCommand)
-        gather_project_mock.return_value = version_command_mock
-        version_command_mock.update_version.side_effect = [
+        current_version = PEP440Version("0.0.0")
+        release_version = PEP440Version("0.0.1")
+        next_version = PEP440Version("0.0.2.dev1")
+        command_mock = MagicMock(spec=GoVersionCommand)
+        gather_commands_mock.return_value = [command_mock]
+        command_mock.update_version.side_effect = [
             VersionUpdate(
                 previous=current_version,
                 new=release_version,
@@ -1783,8 +1790,11 @@ class ReleaseTestCase(unittest.TestCase):
 
         create_release_mock.assert_not_awaited()
 
-        version_command_mock.update_version.assert_has_calls(
-            [call(release_version), call(next_version)]
+        command_mock.update_version.assert_has_calls(
+            [
+                call(release_version, force=False),
+                call(next_version, force=False),
+            ]
         )
 
         git_mock.return_value.add.assert_called_with("MyProject.conf")
